(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('angular2-uuid')) :
    typeof define === 'function' && define.amd ? define('ng2-simple-mq', ['exports', '@angular/core', 'rxjs', 'angular2-uuid'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ng2-simple-mq'] = {}, global.ng.core, global.rxjs, global.angular2Uuid));
}(this, (function (exports, core, rxjs, angular2Uuid) { 'use strict';

    var SimpleMQ = /** @class */ (function () {
        function SimpleMQ() {
            this.mq = {};
            this.subscription = {};
        }
        SimpleMQ.prototype.getQueue = function () {
            return Object.keys(this.mq);
        };
        SimpleMQ.prototype.getSubscription = function () {
            return Object.keys(this.subscription);
        };
        SimpleMQ.prototype.newQueue = function (name) {
            if (name === undefined || this.mq[name]) {
                return false;
            }
            var s = new rxjs.Subject();
            var o = s.asObservable();
            this.mq[name] = { subject: s, observable: o };
            return true;
        };
        SimpleMQ.prototype.delQueue = function (name) {
            var _this = this;
            if (name === undefined || !this.mq[name]) {
                return false;
            }
            var s = this.getSubscription();
            // unsubscribe all subscription for queue 'name'
            s.forEach(function (i) {
                if (_this.subscription[i].name === name) {
                    _this.unsubscribe(i);
                }
            });
            // delete queue 'name' subject and observable
            delete this.mq[name].observable;
            delete this.mq[name].subject;
            delete this.mq[name];
        };
        SimpleMQ.prototype.publish = function (name, msg, lazy) {
            if (lazy === void 0) { lazy = true; }
            if (msg === undefined || name === undefined) {
                return false;
            }
            if (lazy) {
                this.newQueue(name);
            }
            else if (!this.mq[name]) {
                return false;
            }
            this.mq[name].subject.next(msg);
            return true;
        };
        SimpleMQ.prototype.subscribe = function (name, callback, lazy) {
            if (lazy === void 0) { lazy = true; }
            if (name === undefined || callback === undefined) {
                return '';
            }
            if (lazy) {
                this.newQueue(name);
            }
            else if (!this.mq[name]) {
                return '';
            }
            var id = name + '-' + angular2Uuid.UUID.UUID();
            this.subscription[id] = {
                name: name,
                subscription: this.mq[name].observable.subscribe(callback)
            };
            return id;
        };
        SimpleMQ.prototype.unsubscribe = function (id) {
            if (id === undefined || !this.subscription[id]) {
                return false;
            }
            this.subscription[id].subscription.unsubscribe();
            delete this.subscription[id];
        };
        return SimpleMQ;
    }());
    SimpleMQ.decorators = [
        { type: core.Injectable }
    ];

    /*
     * Public API Surface of ng2-simple-mq
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.SimpleMQ = SimpleMQ;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng2-simple-mq.umd.js.map
